@@ -30,12 +30,15 @@
 #include <QtBluetooth/qlowenergycontroller.h>
 #include <QtBluetooth/qlowenergyservice.h>
 #include <QtBluetooth/qlowenergyservicedata.h>
+
+QT_BEGIN_NAMESPACE
 class QBluetoothAddress;
 class QBluetoothHostInfo;
 class QLowEnergyCharacteristicData;
 class QLowEnergyConnectionParameters;
 class QLowEnergyDescriptor;
 class QLowEnergyDescriptorData;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -206,6 +209,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtBluetoothTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtBluetoothTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtBluetoothModuleObject;
 
@@ -218,23 +224,21 @@ enum [[deprecated]] : int {
     SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTICDATA_IDX   = 2, // QList<QLowEnergyCharacteristicData>
     SBK_QTBLUETOOTH_QLIST_QLOWENERGYSERVICEPTR_IDX           = 4, // QList<QLowEnergyService*>
     SBK_QTBLUETOOTH_QLIST_QLOWENERGYCHARACTERISTIC_IDX       = 6, // QList<QLowEnergyCharacteristic>
-    SBK_QTBLUETOOTH_QLIST_QOBJECTPTR_IDX                     = 8, // QList<QObject*>
-    SBK_QTBLUETOOTH_QLIST_QBYTEARRAY_IDX                     = 10, // QList<QByteArray>
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHUUID_IDX                 = 12, // QList<QBluetoothUuid>
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTORDATA_IDX       = 14, // QList<QLowEnergyDescriptorData>
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTOR_IDX           = 16, // QList<QLowEnergyDescriptor>
-    SBK_QTBLUETOOTH_QLIST_QLOWENERGYADVERTISINGPARAMETERS_ADDRESSINFO_IDX = 18, // QList<QLowEnergyAdvertisingParameters::AddressInfo>
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHSERVICEINFO_IDX          = 20, // QList<QBluetoothServiceInfo>
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHHOSTINFO_IDX             = 22, // QList<QBluetoothHostInfo>
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHADDRESS_IDX              = 24, // QList<QBluetoothAddress>
-    SBK_QTBLUETOOTH_QMULTIHASH_QUINT16_QBYTEARRAY_IDX        = 26, // QMultiHash<quint16,QByteArray>
-    SBK_QTBLUETOOTH_QLIST_QUINT16_IDX                        = 28, // QList<quint16>
-    SBK_QTBLUETOOTH_QMULTIHASH_QBLUETOOTHUUID_QBYTEARRAY_IDX = 30, // QMultiHash<QBluetoothUuid,QByteArray>
-    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHDEVICEINFO_IDX           = 32, // QList<QBluetoothDeviceInfo>
-    SBK_QTBLUETOOTH_QLIST_QVARIANT_IDX                       = 34, // QList<QVariant>
-    SBK_QTBLUETOOTH_QLIST_QSTRING_IDX                        = 36, // QList<QString>
-    SBK_QTBLUETOOTH_QMAP_QSTRING_QVARIANT_IDX                = 38, // QMap<QString,QVariant>
-    SBK_QTBLUETOOTH_CONVERTERS_IDX_COUNT                     = 40,
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHUUID_IDX                 = 8, // QList<QBluetoothUuid>
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTORDATA_IDX       = 10, // QList<QLowEnergyDescriptorData>
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYDESCRIPTOR_IDX           = 12, // QList<QLowEnergyDescriptor>
+    SBK_QTBLUETOOTH_QLIST_QLOWENERGYADVERTISINGPARAMETERS_ADDRESSINFO_IDX = 14, // QList<QLowEnergyAdvertisingParameters::AddressInfo>
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHSERVICEINFO_IDX          = 16, // QList<QBluetoothServiceInfo>
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHHOSTINFO_IDX             = 18, // QList<QBluetoothHostInfo>
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHADDRESS_IDX              = 20, // QList<QBluetoothAddress>
+    SBK_QTBLUETOOTH_QMULTIHASH_QUINT16_QBYTEARRAY_IDX        = 22, // QMultiHash<quint16,QByteArray>
+    SBK_QTBLUETOOTH_QLIST_QUINT16_IDX                        = 24, // QList<quint16>
+    SBK_QTBLUETOOTH_QMULTIHASH_QBLUETOOTHUUID_QBYTEARRAY_IDX = 26, // QMultiHash<QBluetoothUuid,QByteArray>
+    SBK_QTBLUETOOTH_QLIST_QBLUETOOTHDEVICEINFO_IDX           = 28, // QList<QBluetoothDeviceInfo>
+    SBK_QTBLUETOOTH_QLIST_QVARIANT_IDX                       = 30, // QList<QVariant>
+    SBK_QTBLUETOOTH_QLIST_QSTRING_IDX                        = 32, // QList<QString>
+    SBK_QTBLUETOOTH_QMAP_QSTRING_QVARIANT_IDX                = 34, // QMap<QString,QVariant>
+    SBK_QTBLUETOOTH_CONVERTERS_IDX_COUNT                     = 36,
 };
 
 // Converter indices
@@ -243,23 +247,21 @@ enum : int {
     SBK_QtBluetooth_QList_QLowEnergyCharacteristicData_IDX   = 1, // QList<QLowEnergyCharacteristicData>
     SBK_QtBluetooth_QList_QLowEnergyServicePTR_IDX           = 2, // QList<QLowEnergyService*>
     SBK_QtBluetooth_QList_QLowEnergyCharacteristic_IDX       = 3, // QList<QLowEnergyCharacteristic>
-    SBK_QtBluetooth_QList_QObjectPTR_IDX                     = 4, // QList<QObject*>
-    SBK_QtBluetooth_QList_QByteArray_IDX                     = 5, // QList<QByteArray>
-    SBK_QtBluetooth_QList_QBluetoothUuid_IDX                 = 6, // QList<QBluetoothUuid>
-    SBK_QtBluetooth_QList_QLowEnergyDescriptorData_IDX       = 7, // QList<QLowEnergyDescriptorData>
-    SBK_QtBluetooth_QList_QLowEnergyDescriptor_IDX           = 8, // QList<QLowEnergyDescriptor>
-    SBK_QtBluetooth_QList_QLowEnergyAdvertisingParameters_AddressInfo_IDX = 9, // QList<QLowEnergyAdvertisingParameters::AddressInfo>
-    SBK_QtBluetooth_QList_QBluetoothServiceInfo_IDX          = 10, // QList<QBluetoothServiceInfo>
-    SBK_QtBluetooth_QList_QBluetoothHostInfo_IDX             = 11, // QList<QBluetoothHostInfo>
-    SBK_QtBluetooth_QList_QBluetoothAddress_IDX              = 12, // QList<QBluetoothAddress>
-    SBK_QtBluetooth_QMultiHash_quint16_QByteArray_IDX        = 13, // QMultiHash<quint16,QByteArray>
-    SBK_QtBluetooth_QList_quint16_IDX                        = 14, // QList<quint16>
-    SBK_QtBluetooth_QMultiHash_QBluetoothUuid_QByteArray_IDX = 15, // QMultiHash<QBluetoothUuid,QByteArray>
-    SBK_QtBluetooth_QList_QBluetoothDeviceInfo_IDX           = 16, // QList<QBluetoothDeviceInfo>
-    SBK_QtBluetooth_QList_QVariant_IDX                       = 17, // QList<QVariant>
-    SBK_QtBluetooth_QList_QString_IDX                        = 18, // QList<QString>
-    SBK_QtBluetooth_QMap_QString_QVariant_IDX                = 19, // QMap<QString,QVariant>
-    SBK_QtBluetooth_CONVERTERS_IDX_COUNT                     = 20,
+    SBK_QtBluetooth_QList_QBluetoothUuid_IDX                 = 4, // QList<QBluetoothUuid>
+    SBK_QtBluetooth_QList_QLowEnergyDescriptorData_IDX       = 5, // QList<QLowEnergyDescriptorData>
+    SBK_QtBluetooth_QList_QLowEnergyDescriptor_IDX           = 6, // QList<QLowEnergyDescriptor>
+    SBK_QtBluetooth_QList_QLowEnergyAdvertisingParameters_AddressInfo_IDX = 7, // QList<QLowEnergyAdvertisingParameters::AddressInfo>
+    SBK_QtBluetooth_QList_QBluetoothServiceInfo_IDX          = 8, // QList<QBluetoothServiceInfo>
+    SBK_QtBluetooth_QList_QBluetoothHostInfo_IDX             = 9, // QList<QBluetoothHostInfo>
+    SBK_QtBluetooth_QList_QBluetoothAddress_IDX              = 10, // QList<QBluetoothAddress>
+    SBK_QtBluetooth_QMultiHash_quint16_QByteArray_IDX        = 11, // QMultiHash<quint16,QByteArray>
+    SBK_QtBluetooth_QList_quint16_IDX                        = 12, // QList<quint16>
+    SBK_QtBluetooth_QMultiHash_QBluetoothUuid_QByteArray_IDX = 13, // QMultiHash<QBluetoothUuid,QByteArray>
+    SBK_QtBluetooth_QList_QBluetoothDeviceInfo_IDX           = 14, // QList<QBluetoothDeviceInfo>
+    SBK_QtBluetooth_QList_QVariant_IDX                       = 15, // QList<QVariant>
+    SBK_QtBluetooth_QList_QString_IDX                        = 16, // QList<QString>
+    SBK_QtBluetooth_QMap_QString_QVariant_IDX                = 17, // QMap<QString,QVariant>
+    SBK_QtBluetooth_CONVERTERS_IDX_COUNT                     = 18,
 };
 // Macros for type check
 
