@@ -244,53 +244,43 @@ extern SbkConverter **SbkPySide6_QtChartsTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTCHARTS_QLIST_INT_IDX                               = 0, // QList<int>
-    SBK_QTCHARTS_QLIST_QOBJECTPTR_IDX                        = 2, // QList<QObject*>
-    SBK_QTCHARTS_QLIST_QBYTEARRAY_IDX                        = 4, // QList<QByteArray>
-    SBK_QTCHARTS_QLIST_QACTIONPTR_IDX                        = 6, // QList<QAction*>
-    SBK_QTCHARTS_QLIST_QLEGENDMARKERPTR_IDX                  = 8, // QList<QLegendMarker*>
-    SBK_QTCHARTS_QLIST_QGRAPHICSITEMPTR_IDX                  = 10, // QList<QGraphicsItem*>
-    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 12, // QList<QRectF>
-    SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 14, // QList<QAbstractAxis*>
-    SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 16, // QList<QAbstractSeries*>
-    SBK_QTCHARTS_QLIST_QREAL_IDX                             = 18, // QList<qreal>
-    SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 20, // QList<QPointF>
-    SBK_QTCHARTS_STD_PAIR_QREAL_QREAL_IDX                    = 22, // std::pair<qreal,qreal>
-    SBK_QTCHARTS_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 24, // QHash<QXYSeries::PointConfiguration,QVariant>
-    SBK_QTCHARTS_QHASH_INT_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 26, // QHash<int,QHash< QXYSeries::PointConfiguration,QVariant>>
-    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 28, // QList<QPieSlice*>
-    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 30, // QList<QCandlestickSet*>
-    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 32, // QList<QBoxSet*>
-    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 34, // QList<QBarSet*>
-    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 36, // QList<QVariant>
-    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 38, // QList<QString>
-    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 40, // QMap<QString,QVariant>
-    SBK_QTCHARTS_CONVERTERS_IDX_COUNT                        = 42,
+    SBK_QTCHARTS_QLIST_QLEGENDMARKERPTR_IDX                  = 2, // QList<QLegendMarker*>
+    SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 4, // QList<QAbstractAxis*>
+    SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 6, // QList<QAbstractSeries*>
+    SBK_QTCHARTS_QLIST_QREAL_IDX                             = 8, // QList<qreal>
+    SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 10, // QList<QPointF>
+    SBK_QTCHARTS_STD_PAIR_QREAL_QREAL_IDX                    = 12, // std::pair<qreal,qreal>
+    SBK_QTCHARTS_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 14, // QHash<QXYSeries::PointConfiguration,QVariant>
+    SBK_QTCHARTS_QHASH_INT_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 16, // QHash<int,QHash<QXYSeries::PointConfiguration,QVariant>>
+    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 18, // QList<QPieSlice*>
+    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 20, // QList<QCandlestickSet*>
+    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 22, // QList<QBoxSet*>
+    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 24, // QList<QBarSet*>
+    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 26, // QList<QVariant>
+    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 28, // QList<QString>
+    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 30, // QMap<QString,QVariant>
+    SBK_QTCHARTS_CONVERTERS_IDX_COUNT                        = 32,
 };
 
 // Converter indices
 enum : int {
     SBK_QtCharts_QList_int_IDX                               = 0, // QList<int>
-    SBK_QtCharts_QList_QObjectPTR_IDX                        = 1, // QList<QObject*>
-    SBK_QtCharts_QList_QByteArray_IDX                        = 2, // QList<QByteArray>
-    SBK_QtCharts_QList_QActionPTR_IDX                        = 3, // QList<QAction*>
-    SBK_QtCharts_QList_QLegendMarkerPTR_IDX                  = 4, // QList<QLegendMarker*>
-    SBK_QtCharts_QList_QGraphicsItemPTR_IDX                  = 5, // QList<QGraphicsItem*>
-    SBK_QtCharts_QList_QRectF_IDX                            = 6, // QList<QRectF>
-    SBK_QtCharts_QList_QAbstractAxisPTR_IDX                  = 7, // QList<QAbstractAxis*>
-    SBK_QtCharts_QList_QAbstractSeriesPTR_IDX                = 8, // QList<QAbstractSeries*>
-    SBK_QtCharts_QList_qreal_IDX                             = 9, // QList<qreal>
-    SBK_QtCharts_QList_QPointF_IDX                           = 10, // QList<QPointF>
-    SBK_QtCharts_std_pair_qreal_qreal_IDX                    = 11, // std::pair<qreal,qreal>
-    SBK_QtCharts_QHash_QXYSeries_PointConfiguration_QVariant_IDX = 12, // QHash<QXYSeries::PointConfiguration,QVariant>
-    SBK_QtCharts_QHash_int_QHash_QXYSeries_PointConfiguration_QVariant_IDX = 13, // QHash<int,QHash< QXYSeries::PointConfiguration,QVariant>>
-    SBK_QtCharts_QList_QPieSlicePTR_IDX                      = 14, // QList<QPieSlice*>
-    SBK_QtCharts_QList_QCandlestickSetPTR_IDX                = 15, // QList<QCandlestickSet*>
-    SBK_QtCharts_QList_QBoxSetPTR_IDX                        = 16, // QList<QBoxSet*>
-    SBK_QtCharts_QList_QBarSetPTR_IDX                        = 17, // QList<QBarSet*>
-    SBK_QtCharts_QList_QVariant_IDX                          = 18, // QList<QVariant>
-    SBK_QtCharts_QList_QString_IDX                           = 19, // QList<QString>
-    SBK_QtCharts_QMap_QString_QVariant_IDX                   = 20, // QMap<QString,QVariant>
-    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 21,
+    SBK_QtCharts_QList_QLegendMarkerPTR_IDX                  = 1, // QList<QLegendMarker*>
+    SBK_QtCharts_QList_QAbstractAxisPTR_IDX                  = 2, // QList<QAbstractAxis*>
+    SBK_QtCharts_QList_QAbstractSeriesPTR_IDX                = 3, // QList<QAbstractSeries*>
+    SBK_QtCharts_QList_qreal_IDX                             = 4, // QList<qreal>
+    SBK_QtCharts_QList_QPointF_IDX                           = 5, // QList<QPointF>
+    SBK_QtCharts_std_pair_qreal_qreal_IDX                    = 6, // std::pair<qreal,qreal>
+    SBK_QtCharts_QHash_QXYSeries_PointConfiguration_QVariant_IDX = 7, // QHash<QXYSeries::PointConfiguration,QVariant>
+    SBK_QtCharts_QHash_int_QHash_QXYSeries_PointConfiguration_QVariant_IDX = 8, // QHash<int,QHash<QXYSeries::PointConfiguration,QVariant>>
+    SBK_QtCharts_QList_QPieSlicePTR_IDX                      = 9, // QList<QPieSlice*>
+    SBK_QtCharts_QList_QCandlestickSetPTR_IDX                = 10, // QList<QCandlestickSet*>
+    SBK_QtCharts_QList_QBoxSetPTR_IDX                        = 11, // QList<QBoxSet*>
+    SBK_QtCharts_QList_QBarSetPTR_IDX                        = 12, // QList<QBarSet*>
+    SBK_QtCharts_QList_QVariant_IDX                          = 13, // QList<QVariant>
+    SBK_QtCharts_QList_QString_IDX                           = 14, // QList<QString>
+    SBK_QtCharts_QMap_QString_QVariant_IDX                   = 15, // QMap<QString,QVariant>
+    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 16,
 };
 // Macros for type check
 
