@@ -198,21 +198,19 @@ enum [[deprecated]] : int {
     SBK_QTDATAVISUALIZATION_QLIST_QSCATTER3DSERIESPTR_IDX    = 16, // QList<QScatter3DSeries*>
     SBK_QTDATAVISUALIZATION_QLIST_QABSTRACT3DAXISPTR_IDX     = 18, // QList<QAbstract3DAxis*>
     SBK_QTDATAVISUALIZATION_QLIST_QBAR3DSERIESPTR_IDX        = 20, // QList<QBar3DSeries*>
-    SBK_QTDATAVISUALIZATION_QLIST_QOBJECTPTR_IDX             = 22, // QList<QObject*>
-    SBK_QTDATAVISUALIZATION_QLIST_QBYTEARRAY_IDX             = 24, // QList<QByteArray>
-    SBK_QTDATAVISUALIZATION_QLIST_FLOAT_IDX                  = 26, // QList<float>
-    SBK_QTDATAVISUALIZATION_QLIST_UCHAR_IDX                  = 28, // QList<uchar>
-    SBK_QTDATAVISUALIZATION_QLIST_UNSIGNEDINT_IDX            = 30, // QList<unsigned int>
-    SBK_QTDATAVISUALIZATION_QLIST_QIMAGEPTR_IDX              = 32, // QList<QImage*>
-    SBK_QTDATAVISUALIZATION_QLIST_QSURFACEDATAITEM_IDX       = 34, // QList<QSurfaceDataItem>
-    SBK_QTDATAVISUALIZATION_QLIST_QSCATTERDATAITEM_IDX       = 36, // QList<QScatterDataItem>
-    SBK_QTDATAVISUALIZATION_QLIST_QBARDATAITEM_IDX           = 38, // QList<QBarDataItem>
-    SBK_QTDATAVISUALIZATION_QLIST_QCOLOR_IDX                 = 40, // QList<QColor>
-    SBK_QTDATAVISUALIZATION_QLIST_QLINEARGRADIENT_IDX        = 42, // QList<QLinearGradient>
-    SBK_QTDATAVISUALIZATION_QLIST_QVARIANT_IDX               = 44, // QList<QVariant>
-    SBK_QTDATAVISUALIZATION_QLIST_QSTRING_IDX                = 46, // QList<QString>
-    SBK_QTDATAVISUALIZATION_QMAP_QSTRING_QVARIANT_IDX        = 48, // QMap<QString,QVariant>
-    SBK_QTDATAVISUALIZATION_CONVERTERS_IDX_COUNT             = 50,
+    SBK_QTDATAVISUALIZATION_QLIST_FLOAT_IDX                  = 22, // QList<float>
+    SBK_QTDATAVISUALIZATION_QLIST_UCHAR_IDX                  = 24, // QList<uchar>
+    SBK_QTDATAVISUALIZATION_QLIST_UNSIGNEDINT_IDX            = 26, // QList<unsigned int>
+    SBK_QTDATAVISUALIZATION_QLIST_QIMAGEPTR_IDX              = 28, // QList<QImage*>
+    SBK_QTDATAVISUALIZATION_QLIST_QSURFACEDATAITEM_IDX       = 30, // QList<QSurfaceDataItem>
+    SBK_QTDATAVISUALIZATION_QLIST_QSCATTERDATAITEM_IDX       = 32, // QList<QScatterDataItem>
+    SBK_QTDATAVISUALIZATION_QLIST_QBARDATAITEM_IDX           = 34, // QList<QBarDataItem>
+    SBK_QTDATAVISUALIZATION_QLIST_QCOLOR_IDX                 = 36, // QList<QColor>
+    SBK_QTDATAVISUALIZATION_QLIST_QLINEARGRADIENT_IDX        = 38, // QList<QLinearGradient>
+    SBK_QTDATAVISUALIZATION_QLIST_QVARIANT_IDX               = 40, // QList<QVariant>
+    SBK_QTDATAVISUALIZATION_QLIST_QSTRING_IDX                = 42, // QList<QString>
+    SBK_QTDATAVISUALIZATION_QMAP_QSTRING_QVARIANT_IDX        = 44, // QMap<QString,QVariant>
+    SBK_QTDATAVISUALIZATION_CONVERTERS_IDX_COUNT             = 46,
 };
 
 // Converter indices
@@ -228,21 +226,19 @@ enum : int {
     SBK_QtDataVisualization_QList_QScatter3DSeriesPTR_IDX    = 8, // QList<QScatter3DSeries*>
     SBK_QtDataVisualization_QList_QAbstract3DAxisPTR_IDX     = 9, // QList<QAbstract3DAxis*>
     SBK_QtDataVisualization_QList_QBar3DSeriesPTR_IDX        = 10, // QList<QBar3DSeries*>
-    SBK_QtDataVisualization_QList_QObjectPTR_IDX             = 11, // QList<QObject*>
-    SBK_QtDataVisualization_QList_QByteArray_IDX             = 12, // QList<QByteArray>
-    SBK_QtDataVisualization_QList_float_IDX                  = 13, // QList<float>
-    SBK_QtDataVisualization_QList_uchar_IDX                  = 14, // QList<uchar>
-    SBK_QtDataVisualization_QList_unsignedint_IDX            = 15, // QList<unsigned int>
-    SBK_QtDataVisualization_QList_QImagePTR_IDX              = 16, // QList<QImage*>
-    SBK_QtDataVisualization_QList_QSurfaceDataItem_IDX       = 17, // QList<QSurfaceDataItem>
-    SBK_QtDataVisualization_QList_QScatterDataItem_IDX       = 18, // QList<QScatterDataItem>
-    SBK_QtDataVisualization_QList_QBarDataItem_IDX           = 19, // QList<QBarDataItem>
-    SBK_QtDataVisualization_QList_QColor_IDX                 = 20, // QList<QColor>
-    SBK_QtDataVisualization_QList_QLinearGradient_IDX        = 21, // QList<QLinearGradient>
-    SBK_QtDataVisualization_QList_QVariant_IDX               = 22, // QList<QVariant>
-    SBK_QtDataVisualization_QList_QString_IDX                = 23, // QList<QString>
-    SBK_QtDataVisualization_QMap_QString_QVariant_IDX        = 24, // QMap<QString,QVariant>
-    SBK_QtDataVisualization_CONVERTERS_IDX_COUNT             = 25,
+    SBK_QtDataVisualization_QList_float_IDX                  = 11, // QList<float>
+    SBK_QtDataVisualization_QList_uchar_IDX                  = 12, // QList<uchar>
+    SBK_QtDataVisualization_QList_unsignedint_IDX            = 13, // QList<unsigned int>
+    SBK_QtDataVisualization_QList_QImagePTR_IDX              = 14, // QList<QImage*>
+    SBK_QtDataVisualization_QList_QSurfaceDataItem_IDX       = 15, // QList<QSurfaceDataItem>
+    SBK_QtDataVisualization_QList_QScatterDataItem_IDX       = 16, // QList<QScatterDataItem>
+    SBK_QtDataVisualization_QList_QBarDataItem_IDX           = 17, // QList<QBarDataItem>
+    SBK_QtDataVisualization_QList_QColor_IDX                 = 18, // QList<QColor>
+    SBK_QtDataVisualization_QList_QLinearGradient_IDX        = 19, // QList<QLinearGradient>
+    SBK_QtDataVisualization_QList_QVariant_IDX               = 20, // QList<QVariant>
+    SBK_QtDataVisualization_QList_QString_IDX                = 21, // QList<QString>
+    SBK_QtDataVisualization_QMap_QString_QVariant_IDX        = 22, // QMap<QString,QVariant>
+    SBK_QtDataVisualization_CONVERTERS_IDX_COUNT             = 23,
 };
 // Macros for type check
 
