@@ -21,6 +21,7 @@
 #include <QtLocation/qgeoroutereply.h>
 #include <QtLocation/qgeorouterequest.h>
 #include <QtLocation/qgeoserviceprovider.h>
+#include <QtLocation/qlocation.h>
 #include <QtLocation/qplacecontent.h>
 #include <QtLocation/qplaceidreply.h>
 #include <QtLocation/qplacereply.h>
@@ -58,150 +59,156 @@ QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
-    SBK_QGEOCODEREPLY_ERROR_IDX                              = 24,
-    SBK_QGEOCODEREPLY_IDX                                    = 22,
-    SBK_QGEOCODINGMANAGER_IDX                                = 26,
-    SBK_QGEOCODINGMANAGERENGINE_IDX                          = 28,
-    SBK_QGEOMANEUVER_INSTRUCTIONDIRECTION_IDX                = 32,
-    SBK_QGEOMANEUVER_IDX                                     = 30,
-    SBK_QGEOROUTE_IDX                                        = 34,
-    SBK_QGEOROUTEREPLY_ERROR_IDX                             = 38,
-    SBK_QGEOROUTEREPLY_IDX                                   = 36,
-    SBK_QGEOROUTEREQUEST_TRAVELMODE_IDX                      = 52,
+    SBK_QGEOCODEREPLY_ERROR_IDX                              = 26,
+    SBK_QGEOCODEREPLY_IDX                                    = 24,
+    SBK_QGEOCODINGMANAGER_IDX                                = 28,
+    SBK_QGEOCODINGMANAGERENGINE_IDX                          = 30,
+    SBK_QGEOMANEUVER_INSTRUCTIONDIRECTION_IDX                = 34,
+    SBK_QGEOMANEUVER_IDX                                     = 32,
+    SBK_QGEOROUTE_IDX                                        = 36,
+    SBK_QGEOROUTEREPLY_ERROR_IDX                             = 40,
+    SBK_QGEOROUTEREPLY_IDX                                   = 38,
+    SBK_QGEOROUTEREQUEST_TRAVELMODE_IDX                      = 54,
     SBK_QFLAGS_QGEOROUTEREQUEST_TRAVELMODE_IDX               = 10,
-    SBK_QGEOROUTEREQUEST_FEATURETYPE_IDX                     = 42,
+    SBK_QGEOROUTEREQUEST_FEATURETYPE_IDX                     = 44,
     SBK_QFLAGS_QGEOROUTEREQUEST_FEATURETYPE_IDX              = 0,
-    SBK_QGEOROUTEREQUEST_FEATUREWEIGHT_IDX                   = 44,
+    SBK_QGEOROUTEREQUEST_FEATUREWEIGHT_IDX                   = 46,
     SBK_QFLAGS_QGEOROUTEREQUEST_FEATUREWEIGHT_IDX            = 2,
-    SBK_QGEOROUTEREQUEST_ROUTEOPTIMIZATION_IDX               = 48,
+    SBK_QGEOROUTEREQUEST_ROUTEOPTIMIZATION_IDX               = 50,
     SBK_QFLAGS_QGEOROUTEREQUEST_ROUTEOPTIMIZATION_IDX        = 6,
-    SBK_QGEOROUTEREQUEST_SEGMENTDETAIL_IDX                   = 50,
+    SBK_QGEOROUTEREQUEST_SEGMENTDETAIL_IDX                   = 52,
     SBK_QFLAGS_QGEOROUTEREQUEST_SEGMENTDETAIL_IDX            = 8,
-    SBK_QGEOROUTEREQUEST_MANEUVERDETAIL_IDX                  = 46,
+    SBK_QGEOROUTEREQUEST_MANEUVERDETAIL_IDX                  = 48,
     SBK_QFLAGS_QGEOROUTEREQUEST_MANEUVERDETAIL_IDX           = 4,
-    SBK_QGEOROUTEREQUEST_IDX                                 = 40,
-    SBK_QGEOROUTESEGMENT_IDX                                 = 54,
-    SBK_QGEOROUTINGMANAGER_IDX                               = 56,
-    SBK_QGEOROUTINGMANAGERENGINE_IDX                         = 58,
-    SBK_QGEOSERVICEPROVIDER_ERROR_IDX                        = 62,
-    SBK_QGEOSERVICEPROVIDER_ROUTINGFEATURE_IDX               = 72,
+    SBK_QGEOROUTEREQUEST_IDX                                 = 42,
+    SBK_QGEOROUTESEGMENT_IDX                                 = 56,
+    SBK_QGEOROUTINGMANAGER_IDX                               = 58,
+    SBK_QGEOROUTINGMANAGERENGINE_IDX                         = 60,
+    SBK_QGEOSERVICEPROVIDER_ERROR_IDX                        = 64,
+    SBK_QGEOSERVICEPROVIDER_ROUTINGFEATURE_IDX               = 74,
     SBK_QFLAGS_QGEOSERVICEPROVIDER_ROUTINGFEATURE_IDX        = 20,
-    SBK_QGEOSERVICEPROVIDER_GEOCODINGFEATURE_IDX             = 64,
+    SBK_QGEOSERVICEPROVIDER_GEOCODINGFEATURE_IDX             = 66,
     SBK_QFLAGS_QGEOSERVICEPROVIDER_GEOCODINGFEATURE_IDX      = 12,
-    SBK_QGEOSERVICEPROVIDER_MAPPINGFEATURE_IDX               = 66,
+    SBK_QGEOSERVICEPROVIDER_MAPPINGFEATURE_IDX               = 68,
     SBK_QFLAGS_QGEOSERVICEPROVIDER_MAPPINGFEATURE_IDX        = 14,
-    SBK_QGEOSERVICEPROVIDER_PLACESFEATURE_IDX                = 70,
+    SBK_QGEOSERVICEPROVIDER_PLACESFEATURE_IDX                = 72,
     SBK_QFLAGS_QGEOSERVICEPROVIDER_PLACESFEATURE_IDX         = 18,
-    SBK_QGEOSERVICEPROVIDER_NAVIGATIONFEATURE_IDX            = 68,
+    SBK_QGEOSERVICEPROVIDER_NAVIGATIONFEATURE_IDX            = 70,
     SBK_QFLAGS_QGEOSERVICEPROVIDER_NAVIGATIONFEATURE_IDX     = 16,
-    SBK_QGEOSERVICEPROVIDER_IDX                              = 60,
-    SBK_QGEOSERVICEPROVIDERFACTORY_IDX                       = 74,
-    SBK_QPLACE_IDX                                           = 76,
-    SBK_QPLACEATTRIBUTE_IDX                                  = 78,
-    SBK_QPLACECATEGORY_IDX                                   = 80,
-    SBK_QPLACECONTACTDETAIL_IDX                              = 82,
-    SBK_QPLACECONTENT_TYPE_IDX                               = 88,
-    SBK_QPLACECONTENT_DATATAG_IDX                            = 86,
-    SBK_QPLACECONTENT_IDX                                    = 84,
-    SBK_QPLACECONTENTREPLY_IDX                               = 90,
-    SBK_QPLACECONTENTREQUEST_IDX                             = 92,
-    SBK_QPLACEDETAILSREPLY_IDX                               = 94,
-    SBK_QPLACEICON_IDX                                       = 96,
-    SBK_QPLACEIDREPLY_OPERATIONTYPE_IDX                      = 100,
-    SBK_QPLACEIDREPLY_IDX                                    = 98,
-    SBK_QPLACEMANAGER_IDX                                    = 102,
-    SBK_QPLACEMANAGERENGINE_IDX                              = 104,
-    SBK_QPLACEMATCHREPLY_IDX                                 = 106,
-    SBK_QPLACEMATCHREQUEST_IDX                               = 108,
-    SBK_QPLACEPROPOSEDSEARCHRESULT_IDX                       = 110,
-    SBK_QPLACERATINGS_IDX                                    = 112,
-    SBK_QPLACEREPLY_ERROR_IDX                                = 116,
-    SBK_QPLACEREPLY_TYPE_IDX                                 = 118,
-    SBK_QPLACEREPLY_IDX                                      = 114,
-    SBK_QPLACERESULT_IDX                                     = 120,
-    SBK_QPLACESEARCHREPLY_IDX                                = 122,
-    SBK_QPLACESEARCHREQUEST_RELEVANCEHINT_IDX                = 126,
-    SBK_QPLACESEARCHREQUEST_IDX                              = 124,
-    SBK_QPLACESEARCHRESULT_SEARCHRESULTTYPE_IDX              = 130,
-    SBK_QPLACESEARCHRESULT_IDX                               = 128,
-    SBK_QPLACESEARCHSUGGESTIONREPLY_IDX                      = 132,
-    SBK_QPLACESUPPLIER_IDX                                   = 134,
-    SBK_QPLACEUSER_IDX                                       = 136,
-    SBK_QTLOCATION_IDX_COUNT                                 = 138,
+    SBK_QGEOSERVICEPROVIDER_IDX                              = 62,
+    SBK_QGEOSERVICEPROVIDERFACTORY_IDX                       = 76,
+    SBK_QLOCATION_VISIBILITY_IDX                             = 80,
+    SBK_QFLAGS_QLOCATION_VISIBILITY_IDX                      = 22,
+    SBK_QTLOCATIONQLOCATION_IDX                              = 78,
+    SBK_QPLACE_IDX                                           = 82,
+    SBK_QPLACEATTRIBUTE_IDX                                  = 84,
+    SBK_QPLACECATEGORY_IDX                                   = 86,
+    SBK_QPLACECONTACTDETAIL_IDX                              = 88,
+    SBK_QPLACECONTENT_TYPE_IDX                               = 94,
+    SBK_QPLACECONTENT_DATATAG_IDX                            = 92,
+    SBK_QPLACECONTENT_IDX                                    = 90,
+    SBK_QPLACECONTENTREPLY_IDX                               = 96,
+    SBK_QPLACECONTENTREQUEST_IDX                             = 98,
+    SBK_QPLACEDETAILSREPLY_IDX                               = 100,
+    SBK_QPLACEICON_IDX                                       = 102,
+    SBK_QPLACEIDREPLY_OPERATIONTYPE_IDX                      = 106,
+    SBK_QPLACEIDREPLY_IDX                                    = 104,
+    SBK_QPLACEMANAGER_IDX                                    = 108,
+    SBK_QPLACEMANAGERENGINE_IDX                              = 110,
+    SBK_QPLACEMATCHREPLY_IDX                                 = 112,
+    SBK_QPLACEMATCHREQUEST_IDX                               = 114,
+    SBK_QPLACEPROPOSEDSEARCHRESULT_IDX                       = 116,
+    SBK_QPLACERATINGS_IDX                                    = 118,
+    SBK_QPLACEREPLY_ERROR_IDX                                = 122,
+    SBK_QPLACEREPLY_TYPE_IDX                                 = 124,
+    SBK_QPLACEREPLY_IDX                                      = 120,
+    SBK_QPLACERESULT_IDX                                     = 126,
+    SBK_QPLACESEARCHREPLY_IDX                                = 128,
+    SBK_QPLACESEARCHREQUEST_RELEVANCEHINT_IDX                = 132,
+    SBK_QPLACESEARCHREQUEST_IDX                              = 130,
+    SBK_QPLACESEARCHRESULT_SEARCHRESULTTYPE_IDX              = 136,
+    SBK_QPLACESEARCHRESULT_IDX                               = 134,
+    SBK_QPLACESEARCHSUGGESTIONREPLY_IDX                      = 138,
+    SBK_QPLACESUPPLIER_IDX                                   = 140,
+    SBK_QPLACEUSER_IDX                                       = 142,
+    SBK_QTLOCATION_IDX_COUNT                                 = 144,
 };
 
 // Type indices
 enum : int {
-    SBK_QGeoCodeReply_Error_IDX                              = 12,
-    SBK_QGeoCodeReply_IDX                                    = 11,
-    SBK_QGeoCodingManager_IDX                                = 13,
-    SBK_QGeoCodingManagerEngine_IDX                          = 14,
-    SBK_QGeoManeuver_InstructionDirection_IDX                = 16,
-    SBK_QGeoManeuver_IDX                                     = 15,
-    SBK_QGeoRoute_IDX                                        = 17,
-    SBK_QGeoRouteReply_Error_IDX                             = 19,
-    SBK_QGeoRouteReply_IDX                                   = 18,
-    SBK_QGeoRouteRequest_TravelMode_IDX                      = 26,
+    SBK_QGeoCodeReply_Error_IDX                              = 13,
+    SBK_QGeoCodeReply_IDX                                    = 12,
+    SBK_QGeoCodingManager_IDX                                = 14,
+    SBK_QGeoCodingManagerEngine_IDX                          = 15,
+    SBK_QGeoManeuver_InstructionDirection_IDX                = 17,
+    SBK_QGeoManeuver_IDX                                     = 16,
+    SBK_QGeoRoute_IDX                                        = 18,
+    SBK_QGeoRouteReply_Error_IDX                             = 20,
+    SBK_QGeoRouteReply_IDX                                   = 19,
+    SBK_QGeoRouteRequest_TravelMode_IDX                      = 27,
     SBK_QFlags_QGeoRouteRequest_TravelMode_IDX               = 5,
-    SBK_QGeoRouteRequest_FeatureType_IDX                     = 21,
+    SBK_QGeoRouteRequest_FeatureType_IDX                     = 22,
     SBK_QFlags_QGeoRouteRequest_FeatureType_IDX              = 0,
-    SBK_QGeoRouteRequest_FeatureWeight_IDX                   = 22,
+    SBK_QGeoRouteRequest_FeatureWeight_IDX                   = 23,
     SBK_QFlags_QGeoRouteRequest_FeatureWeight_IDX            = 1,
-    SBK_QGeoRouteRequest_RouteOptimization_IDX               = 24,
+    SBK_QGeoRouteRequest_RouteOptimization_IDX               = 25,
     SBK_QFlags_QGeoRouteRequest_RouteOptimization_IDX        = 3,
-    SBK_QGeoRouteRequest_SegmentDetail_IDX                   = 25,
+    SBK_QGeoRouteRequest_SegmentDetail_IDX                   = 26,
     SBK_QFlags_QGeoRouteRequest_SegmentDetail_IDX            = 4,
-    SBK_QGeoRouteRequest_ManeuverDetail_IDX                  = 23,
+    SBK_QGeoRouteRequest_ManeuverDetail_IDX                  = 24,
     SBK_QFlags_QGeoRouteRequest_ManeuverDetail_IDX           = 2,
-    SBK_QGeoRouteRequest_IDX                                 = 20,
-    SBK_QGeoRouteSegment_IDX                                 = 27,
-    SBK_QGeoRoutingManager_IDX                               = 28,
-    SBK_QGeoRoutingManagerEngine_IDX                         = 29,
-    SBK_QGeoServiceProvider_Error_IDX                        = 31,
-    SBK_QGeoServiceProvider_RoutingFeature_IDX               = 36,
+    SBK_QGeoRouteRequest_IDX                                 = 21,
+    SBK_QGeoRouteSegment_IDX                                 = 28,
+    SBK_QGeoRoutingManager_IDX                               = 29,
+    SBK_QGeoRoutingManagerEngine_IDX                         = 30,
+    SBK_QGeoServiceProvider_Error_IDX                        = 32,
+    SBK_QGeoServiceProvider_RoutingFeature_IDX               = 37,
     SBK_QFlags_QGeoServiceProvider_RoutingFeature_IDX        = 10,
-    SBK_QGeoServiceProvider_GeocodingFeature_IDX             = 32,
+    SBK_QGeoServiceProvider_GeocodingFeature_IDX             = 33,
     SBK_QFlags_QGeoServiceProvider_GeocodingFeature_IDX      = 6,
-    SBK_QGeoServiceProvider_MappingFeature_IDX               = 33,
+    SBK_QGeoServiceProvider_MappingFeature_IDX               = 34,
     SBK_QFlags_QGeoServiceProvider_MappingFeature_IDX        = 7,
-    SBK_QGeoServiceProvider_PlacesFeature_IDX                = 35,
+    SBK_QGeoServiceProvider_PlacesFeature_IDX                = 36,
     SBK_QFlags_QGeoServiceProvider_PlacesFeature_IDX         = 9,
-    SBK_QGeoServiceProvider_NavigationFeature_IDX            = 34,
+    SBK_QGeoServiceProvider_NavigationFeature_IDX            = 35,
     SBK_QFlags_QGeoServiceProvider_NavigationFeature_IDX     = 8,
-    SBK_QGeoServiceProvider_IDX                              = 30,
-    SBK_QGeoServiceProviderFactory_IDX                       = 37,
-    SBK_QPlace_IDX                                           = 38,
-    SBK_QPlaceAttribute_IDX                                  = 39,
-    SBK_QPlaceCategory_IDX                                   = 40,
-    SBK_QPlaceContactDetail_IDX                              = 41,
-    SBK_QPlaceContent_Type_IDX                               = 44,
-    SBK_QPlaceContent_DataTag_IDX                            = 43,
-    SBK_QPlaceContent_IDX                                    = 42,
-    SBK_QPlaceContentReply_IDX                               = 45,
-    SBK_QPlaceContentRequest_IDX                             = 46,
-    SBK_QPlaceDetailsReply_IDX                               = 47,
-    SBK_QPlaceIcon_IDX                                       = 48,
-    SBK_QPlaceIdReply_OperationType_IDX                      = 50,
-    SBK_QPlaceIdReply_IDX                                    = 49,
-    SBK_QPlaceManager_IDX                                    = 51,
-    SBK_QPlaceManagerEngine_IDX                              = 52,
-    SBK_QPlaceMatchReply_IDX                                 = 53,
-    SBK_QPlaceMatchRequest_IDX                               = 54,
-    SBK_QPlaceProposedSearchResult_IDX                       = 55,
-    SBK_QPlaceRatings_IDX                                    = 56,
-    SBK_QPlaceReply_Error_IDX                                = 58,
-    SBK_QPlaceReply_Type_IDX                                 = 59,
-    SBK_QPlaceReply_IDX                                      = 57,
-    SBK_QPlaceResult_IDX                                     = 60,
-    SBK_QPlaceSearchReply_IDX                                = 61,
-    SBK_QPlaceSearchRequest_RelevanceHint_IDX                = 63,
-    SBK_QPlaceSearchRequest_IDX                              = 62,
-    SBK_QPlaceSearchResult_SearchResultType_IDX              = 65,
-    SBK_QPlaceSearchResult_IDX                               = 64,
-    SBK_QPlaceSearchSuggestionReply_IDX                      = 66,
-    SBK_QPlaceSupplier_IDX                                   = 67,
-    SBK_QPlaceUser_IDX                                       = 68,
-    SBK_QtLocation_IDX_COUNT                                 = 69,
+    SBK_QGeoServiceProvider_IDX                              = 31,
+    SBK_QGeoServiceProviderFactory_IDX                       = 38,
+    SBK_QLocation_Visibility_IDX                             = 40,
+    SBK_QFlags_QLocation_Visibility_IDX                      = 11,
+    SBK_QtLocationQLocation_IDX                              = 39,
+    SBK_QPlace_IDX                                           = 41,
+    SBK_QPlaceAttribute_IDX                                  = 42,
+    SBK_QPlaceCategory_IDX                                   = 43,
+    SBK_QPlaceContactDetail_IDX                              = 44,
+    SBK_QPlaceContent_Type_IDX                               = 47,
+    SBK_QPlaceContent_DataTag_IDX                            = 46,
+    SBK_QPlaceContent_IDX                                    = 45,
+    SBK_QPlaceContentReply_IDX                               = 48,
+    SBK_QPlaceContentRequest_IDX                             = 49,
+    SBK_QPlaceDetailsReply_IDX                               = 50,
+    SBK_QPlaceIcon_IDX                                       = 51,
+    SBK_QPlaceIdReply_OperationType_IDX                      = 53,
+    SBK_QPlaceIdReply_IDX                                    = 52,
+    SBK_QPlaceManager_IDX                                    = 54,
+    SBK_QPlaceManagerEngine_IDX                              = 55,
+    SBK_QPlaceMatchReply_IDX                                 = 56,
+    SBK_QPlaceMatchRequest_IDX                               = 57,
+    SBK_QPlaceProposedSearchResult_IDX                       = 58,
+    SBK_QPlaceRatings_IDX                                    = 59,
+    SBK_QPlaceReply_Error_IDX                                = 61,
+    SBK_QPlaceReply_Type_IDX                                 = 62,
+    SBK_QPlaceReply_IDX                                      = 60,
+    SBK_QPlaceResult_IDX                                     = 63,
+    SBK_QPlaceSearchReply_IDX                                = 64,
+    SBK_QPlaceSearchRequest_RelevanceHint_IDX                = 66,
+    SBK_QPlaceSearchRequest_IDX                              = 65,
+    SBK_QPlaceSearchResult_SearchResultType_IDX              = 68,
+    SBK_QPlaceSearchResult_IDX                               = 67,
+    SBK_QPlaceSearchSuggestionReply_IDX                      = 69,
+    SBK_QPlaceSupplier_IDX                                   = 70,
+    SBK_QPlaceUser_IDX                                       = 71,
+    SBK_QtLocation_IDX_COUNT                                 = 72,
 };
 
 // This variable stores all Python types exported by this module.
@@ -231,13 +238,11 @@ enum [[deprecated]] : int {
     SBK_QTLOCATION_QLIST_QGEOROUTEREQUEST_FEATURETYPE_IDX    = 20, // QList<QGeoRouteRequest::FeatureType>
     SBK_QTLOCATION_QLIST_QGEOROUTE_IDX                       = 22, // QList<QGeoRoute>
     SBK_QTLOCATION_QLIST_QGEOROUTESEGMENT_IDX                = 24, // QList<QGeoRouteSegment>
-    SBK_QTLOCATION_QLIST_QOBJECTPTR_IDX                      = 26, // QList<QObject*>
-    SBK_QTLOCATION_QLIST_QBYTEARRAY_IDX                      = 28, // QList<QByteArray>
-    SBK_QTLOCATION_QLIST_QLOCALE_IDX                         = 30, // QList<QLocale>
-    SBK_QTLOCATION_QLIST_QGEOLOCATION_IDX                    = 32, // QList<QGeoLocation>
-    SBK_QTLOCATION_QLIST_QVARIANT_IDX                        = 34, // QList<QVariant>
-    SBK_QTLOCATION_QLIST_QSTRING_IDX                         = 36, // QList<QString>
-    SBK_QTLOCATION_CONVERTERS_IDX_COUNT                      = 38,
+    SBK_QTLOCATION_QLIST_QLOCALE_IDX                         = 26, // QList<QLocale>
+    SBK_QTLOCATION_QLIST_QGEOLOCATION_IDX                    = 28, // QList<QGeoLocation>
+    SBK_QTLOCATION_QLIST_QVARIANT_IDX                        = 30, // QList<QVariant>
+    SBK_QTLOCATION_QLIST_QSTRING_IDX                         = 32, // QList<QString>
+    SBK_QTLOCATION_CONVERTERS_IDX_COUNT                      = 34,
 };
 
 // Converter indices
@@ -255,13 +260,11 @@ enum : int {
     SBK_QtLocation_QList_QGeoRouteRequest_FeatureType_IDX    = 10, // QList<QGeoRouteRequest::FeatureType>
     SBK_QtLocation_QList_QGeoRoute_IDX                       = 11, // QList<QGeoRoute>
     SBK_QtLocation_QList_QGeoRouteSegment_IDX                = 12, // QList<QGeoRouteSegment>
-    SBK_QtLocation_QList_QObjectPTR_IDX                      = 13, // QList<QObject*>
-    SBK_QtLocation_QList_QByteArray_IDX                      = 14, // QList<QByteArray>
-    SBK_QtLocation_QList_QLocale_IDX                         = 15, // QList<QLocale>
-    SBK_QtLocation_QList_QGeoLocation_IDX                    = 16, // QList<QGeoLocation>
-    SBK_QtLocation_QList_QVariant_IDX                        = 17, // QList<QVariant>
-    SBK_QtLocation_QList_QString_IDX                         = 18, // QList<QString>
-    SBK_QtLocation_CONVERTERS_IDX_COUNT                      = 19,
+    SBK_QtLocation_QList_QLocale_IDX                         = 13, // QList<QLocale>
+    SBK_QtLocation_QList_QGeoLocation_IDX                    = 14, // QList<QGeoLocation>
+    SBK_QtLocation_QList_QVariant_IDX                        = 15, // QList<QVariant>
+    SBK_QtLocation_QList_QString_IDX                         = 16, // QList<QString>
+    SBK_QtLocation_CONVERTERS_IDX_COUNT                      = 17,
 };
 // Macros for type check
 
@@ -309,6 +312,8 @@ template<> inline PyTypeObject *SbkType< ::QGeoServiceProvider::NavigationFeatur
 template<> inline PyTypeObject *SbkType< ::QFlags<QGeoServiceProvider::NavigationFeature> >() { return Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QGeoServiceProvider_NavigationFeature_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QGeoServiceProvider >() { return Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProvider_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QGeoServiceProviderFactory >() { return Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QGeoServiceProviderFactory_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QLocation::Visibility >() { return Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QLocation_Visibility_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QFlags<QLocation::Visibility> >() { return Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QFlags_QLocation_Visibility_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPlace >() { return Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlace_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPlaceAttribute >() { return Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceAttribute_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPlaceCategory >() { return Shiboken::Module::get(SbkPySide6_QtLocationTypeStructs[SBK_QPlaceCategory_IDX]); }
