@@ -42,6 +42,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtMultimediaWidgetsTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtMultimediaWidgetsTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtMultimediaWidgetsModuleObject;
 
@@ -51,21 +54,19 @@ extern SbkConverter **SbkPySide6_QtMultimediaWidgetsTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTMULTIMEDIAWIDGETS_QLIST_INT_IDX                    = 0, // QList<int>
-    SBK_QTMULTIMEDIAWIDGETS_QLIST_QACTIONPTR_IDX             = 2, // QList<QAction*>
-    SBK_QTMULTIMEDIAWIDGETS_QLIST_QVARIANT_IDX               = 4, // QList<QVariant>
-    SBK_QTMULTIMEDIAWIDGETS_QLIST_QSTRING_IDX                = 6, // QList<QString>
-    SBK_QTMULTIMEDIAWIDGETS_QMAP_QSTRING_QVARIANT_IDX        = 8, // QMap<QString,QVariant>
-    SBK_QTMULTIMEDIAWIDGETS_CONVERTERS_IDX_COUNT             = 10,
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QVARIANT_IDX               = 2, // QList<QVariant>
+    SBK_QTMULTIMEDIAWIDGETS_QLIST_QSTRING_IDX                = 4, // QList<QString>
+    SBK_QTMULTIMEDIAWIDGETS_QMAP_QSTRING_QVARIANT_IDX        = 6, // QMap<QString,QVariant>
+    SBK_QTMULTIMEDIAWIDGETS_CONVERTERS_IDX_COUNT             = 8,
 };
 
 // Converter indices
 enum : int {
     SBK_QtMultimediaWidgets_QList_int_IDX                    = 0, // QList<int>
-    SBK_QtMultimediaWidgets_QList_QActionPTR_IDX             = 1, // QList<QAction*>
-    SBK_QtMultimediaWidgets_QList_QVariant_IDX               = 2, // QList<QVariant>
-    SBK_QtMultimediaWidgets_QList_QString_IDX                = 3, // QList<QString>
-    SBK_QtMultimediaWidgets_QMap_QString_QVariant_IDX        = 4, // QMap<QString,QVariant>
-    SBK_QtMultimediaWidgets_CONVERTERS_IDX_COUNT             = 5,
+    SBK_QtMultimediaWidgets_QList_QVariant_IDX               = 1, // QList<QVariant>
+    SBK_QtMultimediaWidgets_QList_QString_IDX                = 2, // QList<QString>
+    SBK_QtMultimediaWidgets_QMap_QString_QVariant_IDX        = 3, // QMap<QString,QVariant>
+    SBK_QtMultimediaWidgets_CONVERTERS_IDX_COUNT             = 4,
 };
 // Macros for type check
 
