@@ -36,6 +36,9 @@
 #if QT_CONFIG(dtls)
 #include <QtNetwork/qdtls.h>
 #endif
+#if QT_CONFIG(networkinterface)
+#include <QtNetwork/qnetworkinterface.h>
+#endif
 #if QT_CONFIG(ssl)
 #include <QtNetwork/qdtls.h>
 #include <QtNetwork/qocspresponse.h>
@@ -45,9 +48,6 @@
 #include <QtNetwork/qsslerror.h>
 #include <QtNetwork/qsslsocket.h>
 #endif
-#ifndef QT_NO_NETWORKINTERFACE
-#include <QtNetwork/qnetworkinterface.h>
-#endif
 
 QT_BEGIN_NAMESPACE
 class QAbstractNetworkCache;
@@ -538,7 +538,7 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QLocalSocket::SocketOption> >(
 template<> inline PyTypeObject *SbkType< ::QLocalSocket >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QLocalSocket_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager::Operation >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_Operation_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAccessManager_IDX]); }
-#ifndef QT_NO_NETWORKINTERFACE
+#if QT_CONFIG(networkinterface)
 template<> inline PyTypeObject *SbkType< ::QNetworkAddressEntry::DnsEligibilityStatus >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_DnsEligibilityStatus_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAddressEntry >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkAddressEntry_IDX]); }
 #endif
@@ -554,7 +554,7 @@ template<> inline PyTypeObject *SbkType< ::QNetworkInformation::TransportMedium
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation::Feature >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_Feature_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInformation::Feature> >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInformation_Feature_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInformation_IDX]); }
-#ifndef QT_NO_NETWORKINTERFACE
+#if QT_CONFIG(networkinterface)
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface::InterfaceFlag >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceFlag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInterface::InterfaceFlag> >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QNetworkInterface_InterfaceFlag_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface::InterfaceType >() { return Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkInterface_InterfaceType_IDX]); }
