@@ -79,6 +79,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtNfcTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtNfcTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtNfcModuleObject;
 
@@ -89,30 +92,26 @@ extern SbkConverter **SbkPySide6_QtNfcTypeConverters;
 enum [[deprecated]] : int {
     SBK_QTNFC_QLIST_INT_IDX                                  = 0, // QList<int>
     SBK_QTNFC_QLIST_QNDEFRECORD_IDX                          = 2, // QList<QNdefRecord>
-    SBK_QTNFC_QLIST_QOBJECTPTR_IDX                           = 4, // QList<QObject*>
-    SBK_QTNFC_QLIST_QBYTEARRAY_IDX                           = 6, // QList<QByteArray>
-    SBK_QTNFC_QLIST_QNDEFMESSAGE_IDX                         = 8, // QList<QNdefMessage>
-    SBK_QTNFC_QLIST_QNDEFNFCICONRECORD_IDX                   = 10, // QList<QNdefNfcIconRecord>
-    SBK_QTNFC_QLIST_QNDEFNFCTEXTRECORD_IDX                   = 12, // QList<QNdefNfcTextRecord>
-    SBK_QTNFC_QLIST_QVARIANT_IDX                             = 14, // QList<QVariant>
-    SBK_QTNFC_QLIST_QSTRING_IDX                              = 16, // QList<QString>
-    SBK_QTNFC_QMAP_QSTRING_QVARIANT_IDX                      = 18, // QMap<QString,QVariant>
-    SBK_QTNFC_CONVERTERS_IDX_COUNT                           = 20,
+    SBK_QTNFC_QLIST_QNDEFMESSAGE_IDX                         = 4, // QList<QNdefMessage>
+    SBK_QTNFC_QLIST_QNDEFNFCICONRECORD_IDX                   = 6, // QList<QNdefNfcIconRecord>
+    SBK_QTNFC_QLIST_QNDEFNFCTEXTRECORD_IDX                   = 8, // QList<QNdefNfcTextRecord>
+    SBK_QTNFC_QLIST_QVARIANT_IDX                             = 10, // QList<QVariant>
+    SBK_QTNFC_QLIST_QSTRING_IDX                              = 12, // QList<QString>
+    SBK_QTNFC_QMAP_QSTRING_QVARIANT_IDX                      = 14, // QMap<QString,QVariant>
+    SBK_QTNFC_CONVERTERS_IDX_COUNT                           = 16,
 };
 
 // Converter indices
 enum : int {
     SBK_QtNfc_QList_int_IDX                                  = 0, // QList<int>
     SBK_QtNfc_QList_QNdefRecord_IDX                          = 1, // QList<QNdefRecord>
-    SBK_QtNfc_QList_QObjectPTR_IDX                           = 2, // QList<QObject*>
-    SBK_QtNfc_QList_QByteArray_IDX                           = 3, // QList<QByteArray>
-    SBK_QtNfc_QList_QNdefMessage_IDX                         = 4, // QList<QNdefMessage>
-    SBK_QtNfc_QList_QNdefNfcIconRecord_IDX                   = 5, // QList<QNdefNfcIconRecord>
-    SBK_QtNfc_QList_QNdefNfcTextRecord_IDX                   = 6, // QList<QNdefNfcTextRecord>
-    SBK_QtNfc_QList_QVariant_IDX                             = 7, // QList<QVariant>
-    SBK_QtNfc_QList_QString_IDX                              = 8, // QList<QString>
-    SBK_QtNfc_QMap_QString_QVariant_IDX                      = 9, // QMap<QString,QVariant>
-    SBK_QtNfc_CONVERTERS_IDX_COUNT                           = 10,
+    SBK_QtNfc_QList_QNdefMessage_IDX                         = 2, // QList<QNdefMessage>
+    SBK_QtNfc_QList_QNdefNfcIconRecord_IDX                   = 3, // QList<QNdefNfcIconRecord>
+    SBK_QtNfc_QList_QNdefNfcTextRecord_IDX                   = 4, // QList<QNdefNfcTextRecord>
+    SBK_QtNfc_QList_QVariant_IDX                             = 5, // QList<QVariant>
+    SBK_QtNfc_QList_QString_IDX                              = 6, // QList<QString>
+    SBK_QtNfc_QMap_QString_QVariant_IDX                      = 7, // QMap<QString,QVariant>
+    SBK_QtNfc_CONVERTERS_IDX_COUNT                           = 8,
 };
 // Macros for type check
 
