@@ -130,12 +130,10 @@ enum [[deprecated]] : int {
     SBK_QTPOSITIONING_QLIST_QGEOCOORDINATE_IDX               = 2, // QList<QGeoCoordinate>
     SBK_QTPOSITIONING_QMAP_QSTRING_QVARIANT_IDX              = 4, // QMap<QString,QVariant>
     SBK_QTPOSITIONING_QLIST_QVARIANT_IDX                     = 6, // QList<QVariant>
-    SBK_QTPOSITIONING_QLIST_QOBJECTPTR_IDX                   = 8, // QList<QObject*>
-    SBK_QTPOSITIONING_QLIST_QBYTEARRAY_IDX                   = 10, // QList<QByteArray>
-    SBK_QTPOSITIONING_QLIST_QGEOSATELLITEINFO_IDX            = 12, // QList<QGeoSatelliteInfo>
-    SBK_QTPOSITIONING_QLIST_QGEOAREAMONITORINFO_IDX          = 14, // QList<QGeoAreaMonitorInfo>
-    SBK_QTPOSITIONING_QLIST_QSTRING_IDX                      = 16, // QList<QString>
-    SBK_QTPOSITIONING_CONVERTERS_IDX_COUNT                   = 18,
+    SBK_QTPOSITIONING_QLIST_QGEOSATELLITEINFO_IDX            = 8, // QList<QGeoSatelliteInfo>
+    SBK_QTPOSITIONING_QLIST_QGEOAREAMONITORINFO_IDX          = 10, // QList<QGeoAreaMonitorInfo>
+    SBK_QTPOSITIONING_QLIST_QSTRING_IDX                      = 12, // QList<QString>
+    SBK_QTPOSITIONING_CONVERTERS_IDX_COUNT                   = 14,
 };
 
 // Converter indices
@@ -144,12 +142,10 @@ enum : int {
     SBK_QtPositioning_QList_QGeoCoordinate_IDX               = 1, // QList<QGeoCoordinate>
     SBK_QtPositioning_QMap_QString_QVariant_IDX              = 2, // QMap<QString,QVariant>
     SBK_QtPositioning_QList_QVariant_IDX                     = 3, // QList<QVariant>
-    SBK_QtPositioning_QList_QObjectPTR_IDX                   = 4, // QList<QObject*>
-    SBK_QtPositioning_QList_QByteArray_IDX                   = 5, // QList<QByteArray>
-    SBK_QtPositioning_QList_QGeoSatelliteInfo_IDX            = 6, // QList<QGeoSatelliteInfo>
-    SBK_QtPositioning_QList_QGeoAreaMonitorInfo_IDX          = 7, // QList<QGeoAreaMonitorInfo>
-    SBK_QtPositioning_QList_QString_IDX                      = 8, // QList<QString>
-    SBK_QtPositioning_CONVERTERS_IDX_COUNT                   = 9,
+    SBK_QtPositioning_QList_QGeoSatelliteInfo_IDX            = 4, // QList<QGeoSatelliteInfo>
+    SBK_QtPositioning_QList_QGeoAreaMonitorInfo_IDX          = 5, // QList<QGeoAreaMonitorInfo>
+    SBK_QtPositioning_QList_QString_IDX                      = 6, // QList<QString>
+    SBK_QtPositioning_CONVERTERS_IDX_COUNT                   = 7,
 };
 // Macros for type check
 
