@@ -198,13 +198,12 @@ enum [[deprecated]] : int {
     SBK_QTQML_QMAP_QSTRING_QVARIANT_IDX                      = 4, // QMap<QString,QVariant>
     SBK_QTQML_QHASH_QSTRING_QVARIANT_IDX                     = 6, // QHash<QString,QVariant>
     SBK_QTQML_QLIST_QJSVALUE_IDX                             = 8, // QList<QJSValue>
-    SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 10, // QList<QObject*>
-    SBK_QTQML_QLIST_QBYTEARRAY_IDX                           = 12, // QList<QByteArray>
-    SBK_QTQML_QLIST_QQMLCONTEXT_PROPERTYPAIR_IDX             = 14, // QList<QQmlContext::PropertyPair>
-    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 16, // QList<QQmlAbstractUrlInterceptor*>
-    SBK_QTQML_QLIST_QVARIANT_IDX                             = 18, // QList<QVariant>
-    SBK_QTQML_QLIST_QSTRING_IDX                              = 20, // QList<QString>
-    SBK_QTQML_CONVERTERS_IDX_COUNT                           = 22,
+    SBK_QTQML_QLIST_QQMLCONTEXT_PROPERTYPAIR_IDX             = 10, // QList<QQmlContext::PropertyPair>
+    SBK_QTQML_QLIST_QQMLABSTRACTURLINTERCEPTORPTR_IDX        = 12, // QList<QQmlAbstractUrlInterceptor*>
+    SBK_QTQML_QLIST_QOBJECTPTR_IDX                           = 14, // QList<QObject*>
+    SBK_QTQML_QLIST_QVARIANT_IDX                             = 16, // QList<QVariant>
+    SBK_QTQML_QLIST_QSTRING_IDX                              = 18, // QList<QString>
+    SBK_QTQML_CONVERTERS_IDX_COUNT                           = 20,
 };
 
 // Converter indices
@@ -214,13 +213,12 @@ enum : int {
     SBK_QtQml_QMap_QString_QVariant_IDX                      = 2, // QMap<QString,QVariant>
     SBK_QtQml_QHash_QString_QVariant_IDX                     = 3, // QHash<QString,QVariant>
     SBK_QtQml_QList_QJSValue_IDX                             = 4, // QList<QJSValue>
-    SBK_QtQml_QList_QObjectPTR_IDX                           = 5, // QList<QObject*>
-    SBK_QtQml_QList_QByteArray_IDX                           = 6, // QList<QByteArray>
-    SBK_QtQml_QList_QQmlContext_PropertyPair_IDX             = 7, // QList<QQmlContext::PropertyPair>
-    SBK_QtQml_QList_QQmlAbstractUrlInterceptorPTR_IDX        = 8, // QList<QQmlAbstractUrlInterceptor*>
-    SBK_QtQml_QList_QVariant_IDX                             = 9, // QList<QVariant>
-    SBK_QtQml_QList_QString_IDX                              = 10, // QList<QString>
-    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 11,
+    SBK_QtQml_QList_QQmlContext_PropertyPair_IDX             = 5, // QList<QQmlContext::PropertyPair>
+    SBK_QtQml_QList_QQmlAbstractUrlInterceptorPTR_IDX        = 6, // QList<QQmlAbstractUrlInterceptor*>
+    SBK_QtQml_QList_QObjectPTR_IDX                           = 7, // QList<QObject*>
+    SBK_QtQml_QList_QVariant_IDX                             = 8, // QList<QVariant>
+    SBK_QtQml_QList_QString_IDX                              = 9, // QList<QString>
+    SBK_QtQml_CONVERTERS_IDX_COUNT                           = 10,
 };
 // Macros for type check
 
