@@ -227,31 +227,29 @@ extern SbkConverter **SbkPySide6_QtSensorsTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTSENSORS_QLIST_INT_IDX                              = 0, // QList<int>
-    SBK_QTSENSORS_QLIST_QOBJECTPTR_IDX                       = 2, // QList<QObject*>
-    SBK_QTSENSORS_QLIST_QBYTEARRAY_IDX                       = 4, // QList<QByteArray>
-    SBK_QTSENSORS_STD_PAIR_INT_INT_IDX                       = 6, // std::pair<int,int>
-    SBK_QTSENSORS_QLIST_STD_PAIR_INT_INT_IDX                 = 8, // QList<std::pair< int,int>>
-    SBK_QTSENSORS_QLIST_QSENSORFILTERPTR_IDX                 = 10, // QList<QSensorFilter*>
-    SBK_QTSENSORS_QLIST_QOUTPUTRANGE_IDX                     = 12, // QList<qoutputrange>
-    SBK_QTSENSORS_QLIST_QVARIANT_IDX                         = 14, // QList<QVariant>
-    SBK_QTSENSORS_QLIST_QSTRING_IDX                          = 16, // QList<QString>
-    SBK_QTSENSORS_QMAP_QSTRING_QVARIANT_IDX                  = 18, // QMap<QString,QVariant>
-    SBK_QTSENSORS_CONVERTERS_IDX_COUNT                       = 20,
+    SBK_QTSENSORS_STD_PAIR_INT_INT_IDX                       = 2, // std::pair<int,int>
+    SBK_QTSENSORS_QLIST_STD_PAIR_INT_INT_IDX                 = 4, // QList<std::pair<int,int>>
+    SBK_QTSENSORS_QLIST_QSENSORFILTERPTR_IDX                 = 6, // QList<QSensorFilter*>
+    SBK_QTSENSORS_QLIST_QOUTPUTRANGE_IDX                     = 8, // QList<qoutputrange>
+    SBK_QTSENSORS_QLIST_QBYTEARRAY_IDX                       = 10, // QList<QByteArray>
+    SBK_QTSENSORS_QLIST_QVARIANT_IDX                         = 12, // QList<QVariant>
+    SBK_QTSENSORS_QLIST_QSTRING_IDX                          = 14, // QList<QString>
+    SBK_QTSENSORS_QMAP_QSTRING_QVARIANT_IDX                  = 16, // QMap<QString,QVariant>
+    SBK_QTSENSORS_CONVERTERS_IDX_COUNT                       = 18,
 };
 
 // Converter indices
 enum : int {
     SBK_QtSensors_QList_int_IDX                              = 0, // QList<int>
-    SBK_QtSensors_QList_QObjectPTR_IDX                       = 1, // QList<QObject*>
-    SBK_QtSensors_QList_QByteArray_IDX                       = 2, // QList<QByteArray>
-    SBK_QtSensors_std_pair_int_int_IDX                       = 3, // std::pair<int,int>
-    SBK_QtSensors_QList_std_pair_int_int_IDX                 = 4, // QList<std::pair< int,int>>
-    SBK_QtSensors_QList_QSensorFilterPTR_IDX                 = 5, // QList<QSensorFilter*>
-    SBK_QtSensors_QList_qoutputrange_IDX                     = 6, // QList<qoutputrange>
-    SBK_QtSensors_QList_QVariant_IDX                         = 7, // QList<QVariant>
-    SBK_QtSensors_QList_QString_IDX                          = 8, // QList<QString>
-    SBK_QtSensors_QMap_QString_QVariant_IDX                  = 9, // QMap<QString,QVariant>
-    SBK_QtSensors_CONVERTERS_IDX_COUNT                       = 10,
+    SBK_QtSensors_std_pair_int_int_IDX                       = 1, // std::pair<int,int>
+    SBK_QtSensors_QList_std_pair_int_int_IDX                 = 2, // QList<std::pair<int,int>>
+    SBK_QtSensors_QList_QSensorFilterPTR_IDX                 = 3, // QList<QSensorFilter*>
+    SBK_QtSensors_QList_qoutputrange_IDX                     = 4, // QList<qoutputrange>
+    SBK_QtSensors_QList_QByteArray_IDX                       = 5, // QList<QByteArray>
+    SBK_QtSensors_QList_QVariant_IDX                         = 6, // QList<QVariant>
+    SBK_QtSensors_QList_QString_IDX                          = 7, // QList<QString>
+    SBK_QtSensors_QMap_QString_QVariant_IDX                  = 8, // QMap<QString,QVariant>
+    SBK_QtSensors_CONVERTERS_IDX_COUNT                       = 9,
 };
 // Macros for type check
 
