@@ -64,6 +64,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtTestTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtTestTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtTestModuleObject;
 
@@ -74,22 +77,18 @@ extern SbkConverter **SbkPySide6_QtTestTypeConverters;
 enum [[deprecated]] : int {
     SBK_QTTEST_QLIST_INT_IDX                                 = 0, // QList<int>
     SBK_QTTEST_QLIST_QVARIANT_IDX                            = 2, // QList<QVariant>
-    SBK_QTTEST_QLIST_QOBJECTPTR_IDX                          = 4, // QList<QObject*>
-    SBK_QTTEST_QLIST_QBYTEARRAY_IDX                          = 6, // QList<QByteArray>
-    SBK_QTTEST_QLIST_QSTRING_IDX                             = 8, // QList<QString>
-    SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                     = 10, // QMap<QString,QVariant>
-    SBK_QTTEST_CONVERTERS_IDX_COUNT                          = 12,
+    SBK_QTTEST_QLIST_QSTRING_IDX                             = 4, // QList<QString>
+    SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                     = 6, // QMap<QString,QVariant>
+    SBK_QTTEST_CONVERTERS_IDX_COUNT                          = 8,
 };
 
 // Converter indices
 enum : int {
     SBK_QtTest_QList_int_IDX                                 = 0, // QList<int>
     SBK_QtTest_QList_QVariant_IDX                            = 1, // QList<QVariant>
-    SBK_QtTest_QList_QObjectPTR_IDX                          = 2, // QList<QObject*>
-    SBK_QtTest_QList_QByteArray_IDX                          = 3, // QList<QByteArray>
-    SBK_QtTest_QList_QString_IDX                             = 4, // QList<QString>
-    SBK_QtTest_QMap_QString_QVariant_IDX                     = 5, // QMap<QString,QVariant>
-    SBK_QtTest_CONVERTERS_IDX_COUNT                          = 6,
+    SBK_QtTest_QList_QString_IDX                             = 2, // QList<QString>
+    SBK_QtTest_QMap_QString_QVariant_IDX                     = 3, // QMap<QString,QVariant>
+    SBK_QtTest_CONVERTERS_IDX_COUNT                          = 4,
 };
 // Macros for type check
 
