@@ -4,10 +4,13 @@
 #ifndef PYSIDE_QENUM_H
 #define PYSIDE_QENUM_H
 
+#include <sbkpython.h>
+
 #include <pysidemacros.h>
+
 #include <vector>
 
-namespace PySide { namespace QEnum {
+namespace PySide::QEnum {
 
 // PYSIDE-957: Support the QEnum macro
 PYSIDE_API PyObject *QEnumMacro(PyObject *, bool);
@@ -15,7 +18,6 @@ PYSIDE_API int isFlag(PyObject *);
 PYSIDE_API std::vector<PyObject *> resolveDelayedQEnums(PyTypeObject *);
 PYSIDE_API void init();
 
-} // namespace QEnum
-} // namespace PySide
+} // namespace PySide::QEnum
 
 #endif
